==> knative-model-6.2.0-sources.jar: io/fabric8/knative/sources/v1/ContainerSourceFluentImpl.java <==
package io.fabric8.knative.sources.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerSourceFluentImpl<A extends ContainerSourceFluent<A>> extends BaseFluent<A> implements ContainerSourceFluent<A>{
  public ContainerSourceFluentImpl() {
  }
  public ContainerSourceFluentImpl(ContainerSource instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ContainerSourceSpecBuilder spec;
  private ContainerSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ContainerSourceFluent.MetadataNested<A> withNewMetadata() {
    return new ContainerSourceFluentImpl.MetadataNestedImpl();
  }
  public ContainerSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ContainerSourceFluentImpl.MetadataNestedImpl(item);
  }
  public ContainerSourceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ContainerSourceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ContainerSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ContainerSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ContainerSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ContainerSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ContainerSourceFluent.SpecNested<A> withNewSpec() {
    return new ContainerSourceFluentImpl.SpecNestedImpl();
  }
  public ContainerSourceFluent.SpecNested<A> withNewSpecLike(ContainerSourceSpec item) {
    return new ContainerSourceFluentImpl.SpecNestedImpl(item);
  }
  public ContainerSourceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ContainerSourceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ContainerSourceSpecBuilder().build());
  }
  public ContainerSourceFluent.SpecNested<A> editOrNewSpecLike(ContainerSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ContainerSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ContainerSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ContainerSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ContainerSourceFluent.StatusNested<A> withNewStatus() {
    return new ContainerSourceFluentImpl.StatusNestedImpl();
  }
  public ContainerSourceFluent.StatusNested<A> withNewStatusLike(ContainerSourceStatus item) {
    return new ContainerSourceFluentImpl.StatusNestedImpl(item);
  }
  public ContainerSourceFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ContainerSourceFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ContainerSourceStatusBuilder().build());
  }
  public ContainerSourceFluent.StatusNested<A> editOrNewStatusLike(ContainerSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerSourceFluentImpl that = (ContainerSourceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ContainerSourceFluent.MetadataNested<N>> implements ContainerSourceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ContainerSourceSpecFluentImpl<ContainerSourceFluent.SpecNested<N>> implements ContainerSourceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ContainerSourceSpec item) {
      this.builder = new ContainerSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ContainerSourceSpecBuilder(this);
    }
    ContainerSourceSpecBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ContainerSourceStatusFluentImpl<ContainerSourceFluent.StatusNested<N>> implements ContainerSourceFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ContainerSourceStatus item) {
      this.builder = new ContainerSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ContainerSourceStatusBuilder(this);
    }
    ContainerSourceStatusBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/sources/v1/ContainerSourceFluentImpl.java <==
package io.fabric8.knative.sources.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerSourceFluentImpl<A extends ContainerSourceFluent<A>> extends BaseFluent<A> implements ContainerSourceFluent<A>{
  public ContainerSourceFluentImpl() {
  }
  public ContainerSourceFluentImpl(ContainerSource instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ContainerSourceSpecBuilder spec;
  private ContainerSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ContainerSourceFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ContainerSourceFluentImpl.MetadataNestedImpl();
  }
  public ContainerSourceFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ContainerSourceFluentImpl.MetadataNestedImpl(item);
  }
  public ContainerSourceFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ContainerSourceFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ContainerSourceFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ContainerSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ContainerSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ContainerSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ContainerSourceFluentImpl.SpecNested<A> withNewSpec() {
    return new ContainerSourceFluentImpl.SpecNestedImpl();
  }
  public ContainerSourceFluentImpl.SpecNested<A> withNewSpecLike(ContainerSourceSpec item) {
    return new ContainerSourceFluentImpl.SpecNestedImpl(item);
  }
  public ContainerSourceFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ContainerSourceFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ContainerSourceSpecBuilder().build());
  }
  public ContainerSourceFluentImpl.SpecNested<A> editOrNewSpecLike(ContainerSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ContainerSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ContainerSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ContainerSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ContainerSourceFluentImpl.StatusNested<A> withNewStatus() {
    return new ContainerSourceFluentImpl.StatusNestedImpl();
  }
  public ContainerSourceFluentImpl.StatusNested<A> withNewStatusLike(ContainerSourceStatus item) {
    return new ContainerSourceFluentImpl.StatusNestedImpl(item);
  }
  public ContainerSourceFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ContainerSourceFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ContainerSourceStatusBuilder().build());
  }
  public ContainerSourceFluentImpl.StatusNested<A> editOrNewStatusLike(ContainerSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerSourceFluentImpl that = (ContainerSourceFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ContainerSourceFluentImpl.MetadataNested<N>> implements ContainerSourceFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ContainerSourceSpecFluentImpl<ContainerSourceFluentImpl.SpecNested<N>> implements ContainerSourceFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ContainerSourceSpec item) {
      this.builder = new ContainerSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ContainerSourceSpecBuilder(this);
    }
    ContainerSourceSpecBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ContainerSourceStatusFluentImpl<ContainerSourceFluentImpl.StatusNested<N>> implements ContainerSourceFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ContainerSourceStatus item) {
      this.builder = new ContainerSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ContainerSourceStatusBuilder(this);
    }
    ContainerSourceStatusBuilder builder;
    public N and() {
      return (N) ContainerSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
